@@ -1,7 +1,8 @@
 import shutil
 
 from pipenv import environments
-from pipenv.vendor import click, vistir
+from pipenv.utils.funktools import handle_remove_readonly
+from pipenv.vendor import click
 
 
 def do_clear(project):
@@ -9,14 +10,12 @@ def do_clear(project):
 
     click.secho("Clearing caches...", bold=True)
     try:
-        shutil.rmtree(
-            project.s.PIPENV_CACHE_DIR, onerror=vistir.path.handle_remove_readonly
-        )
+        shutil.rmtree(project.s.PIPENV_CACHE_DIR, onerror=handle_remove_readonly)
         # Other processes may be writing into this directory simultaneously.
         shutil.rmtree(
             locations.USER_CACHE_DIR,
             ignore_errors=environments.PIPENV_IS_CI,
-            onerror=vistir.path.handle_remove_readonly,
+            onerror=handle_remove_readonly,
         )
     except OSError as e:
         # Ignore FileNotFoundError. This is needed for Python 2.7.
