@@ -44,6 +44,8 @@ def do_update(
     )
     packages = [p for p in packages if p]
     editable = [p for p in editable_packages if p]
+    if not outdated:
+        outdated = bool(dry_run)
     if not packages:
         click.echo(
             "{} {} {} {}{}".format(
@@ -59,7 +61,7 @@ def do_update(
             clear=clear,
             pre=pre,
             pypi_mirror=pypi_mirror,
-            write=not quiet,
+            write=not outdated,
         )
     else:
         upgrade(
@@ -75,8 +77,6 @@ def do_update(
             lock_only=lock_only,
         )
 
-    if not outdated:
-        outdated = bool(dry_run)
     if outdated:
         do_outdated(
             project,
@@ -84,19 +84,19 @@ def do_update(
             pre=pre,
             pypi_mirror=pypi_mirror,
         )
-
-    do_sync(
-        project,
-        dev=dev,
-        categories=categories,
-        python=python,
-        bare=bare,
-        user=False,
-        clear=clear,
-        unused=False,
-        pypi_mirror=pypi_mirror,
-        extra_pip_args=extra_pip_args,
-    )
+    else:
+        do_sync(
+            project,
+            dev=dev,
+            categories=categories,
+            python=python,
+            bare=bare,
+            user=False,
+            clear=clear,
+            unused=False,
+            pypi_mirror=pypi_mirror,
+            extra_pip_args=extra_pip_args,
+        )
 
 
 def upgrade(
@@ -131,7 +131,7 @@ def upgrade(
         pipfile_category = get_pipfile_category_using_lockfile_section(category)
 
         for package in package_args[:]:
-            install_req = expansive_install_req_from_line(package, expand_env=True)
+            install_req, _ = expansive_install_req_from_line(package, expand_env=True)
             if index_name:
                 install_req.index = index_name
             name, normalized_name, pipfile_entry = project.generate_package_pipfile_entry(
